#!/usr/dist/bin/wishx -f

#
# network.tcl
# Copyright (C) 1995 by John Heidemann
# This program is released under the Gnu Public License, version 2.
# Comments to <johnh@isi.edu>.
#

proc network_config {} {
	set f [open "/proc/net/route" r]
	set tm "net"
	while {[gets $f l] >= 0} {
		if [string match "eth*" $l] {
			set tm "eth"
		}
		if [string match "ppp*" $l] {
			set tm "ppp"
		}
	}
	close $f
	.network config -text $tm
}

proc network_update {} {
	global monitor_module
	if {$monitor_module(network)} {
		network_config
		# almost every two minutes
		after 119000 network_update
	}
}

proc network_command {prog} {
#	system $prog
	set f [open "|$prog" r]
#	while {[gets $f l] >= 0} {
#		puts $l
#	}
	# ignore return code
	catch {close $f}

	network_config
}

proc console_command {prog} {
	eval "exec $prog </dev/null >>/dev/console"
	set f [open "|$prog" r]
#	while {[gets $f l] >= 0} {
#		puts $l
#	}
	# ignore return code
	catch {close $f}

	network_config
}

proc network_generic_commands {w cmds} {
	# puts "ngc, $cmds"
	set re "\[ \t\]*(\[^: \]+):\[ \t\]*(\[^;\]*);"
	while {[regexp $re $cmds whole key value] != 0} {
		# puts "network_generic_commands: <$key> <$value>"
		$w.m add command -label $key -command "console_command {$value}"
		regsub $re $cmds {} cmds
	}
}

proc network_start {} {
	global rdb
	set_rdb_default network.row 1
	set_rdb_default network.commands ""
	mk_rows $rdb(network.row)
	menubutton .network -text "network" -font $rdb(font) -fg $rdb(fg) -bg $rdb(bg) -menu .network.m
	menu .network.m
	foreach i {ppp_on ppp_off} {
		.network.m add command -label $i -command "network_command $i"
	}
#	.network.m add command -label "ping ashby" -command "network_command {ping ashby -c 1}"
	network_generic_commands .network $rdb(network.commands)
#	network_generic_commands .network { inc: remote_inc -v ;   inc_indirect: remote_inc -v -m indirect ;      test: echo test;       test-console: echo test;}
	pack .network -side $rdb(side) -in ".row$rdb(network.row)"
	network_update
}

proc network_stop {} {
	destroy .network
}

